==> nextcloud-app-tasks-0.15.0-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/tasks/l10n/eo.js <==
OC.L10N.register(
    "tasks",
    {
    "Important" : "Grava",
    "Today" : "Hodiaŭ",
    "Week" : "Semajno",
    "All" : "Ĉio",
    "Current" : "Nuna",
    "Completed" : "Plenumita",
    "Tasks" : "Taskoj",
    "The Tasks app for Nextcloud" : "Aplikaĵo „Taskoj“ por Nextcloud",
    "Default list" : "Defaŭlta listo",
    "Visibility of Smart Collections" : "Videbleco de aŭtomataj kolektoj",
    "Hidden" : "Nevidebla",
    "Visible" : "Videbla",
    "Automatic" : "Aŭtomata",
    "Share with users or groups" : "Kunhavigi kun uzantoj aŭ grupoj",
    "No users or groups" : "Neniu uzanto aŭ grupo",
    "Can edit" : "Povas redakti",
    "Unable to delete the share." : "Ne eblas forigi la kunhavon.",
    "Unable to change permissions." : "Ne eblas ŝanĝi permesojn.",
    "Edit" : "Redakti",
    "Copy private link" : "Kopii privatan ligilon",
    "Copied" : "Kopiita",
    "Export" : "Eksporti",
    "Delete" : "Forigi",
    "Unshare" : "Malkunhavigi",
    "This will delete the calendar \"{calendar}\" and all corresponding events and tasks." : "Tio forigos la kalendaron „{calendar}“ kaj ĉiujn ties eventojn kaj taskojn.",
    "Calendar link copied to clipboard." : "Kalendara ligilo kopiita al tondujo",
    "Calendar link could not be copied to clipboard." : "Kalendara ligilo ne eblis esti kopiita al tondujo",
    "The name \"{calendar}\" is already used." : "La nomo „{calendar}“ jam uziĝas.",
    "An empty name is not allowed." : "Malplena nomo ne permesatas.",
    "_Shared with {num} entity_::_Shared with {num} entities_" : ["Kunhavigitaj kun {num} ento","Kunhavigitaj kun {num} entoj"],
    "Name" : "Nomo",
    "Deleted" : "Forigita",
    "Restore" : "Restaŭri",
    "Delete permanently" : "Forigi por ĉiam",
    "Untitled event" : "Sentitola okazaĵo",
    "Select a calendar" : "Elekti kalendaron",
    "Delete all completed tasks." : "Forigi ĉiujn plenumitajn taskojn.",
    "Delete completed tasks." : "Forigi plenumitajn taskojn.",
    "Deleted all completed tasks from calendar \"{calendar}\"." : "Forigi ĉiujn plenumitajn taskojn el kalendaro „{calendar}“.",
    "No errors" : "Neniu eraro",
    "Open your browser console for more details" : "Malfermu vian retumilan konzolon por pli da detaloj",
    "_This will delete {taskCount} completed task and its subtasks from calendar \"{calendar}\"._::_This will delete {taskCount} completed tasks and their subtasks from calendar \"{calendar}\"._" : ["Tio forigos {taskCount} plenumitan taskon kaj ties subtaskojn el la kalendaro „{calendar}“.","Tio forigos {taskCount} plenumitajn taskojn kaj ties subtaskojn el la kalendaro „{calendar}“."],
    "_Could not delete {failedCount} task._::_Could not delete {failedCount} tasks._" : ["Ne eblis forigi {failedCount} taskon.","Ne eblis forigi {failedCount} taskojn."],
    "Add an important task to \"{calendar}\"…" : "Aldoni gravan taskon al „{calendar}“...",
    "Add a task due today to \"{calendar}\"…" : "Aldoni taskon kun hodiaŭa limdato al „{calendar}“...",
    "Add a current task to \"{calendar}\"…" : "Aldoni nunan taskon al „{calendar}“...",
    "Add a task to \"{calendar}\"…" : "Aldoni taskon al „{calendar}“...",
    "Change sort order" : "Ŝanĝi ordigon",
    "Sort by completed state, due date, priority, start date and summary." : "Ordigi laŭ plenumstato, limdato, prioritato, komencdato kaj resumo.",
    "Start date" : "Komencdato",
    "Due date" : "Limdato",
    "Created date" : "Krea dato",
    "Last modified" : "Laste modifita",
    "Completed date" : "Plenumdato",
    "Priority" : "Prioritato",
    "Sort by priority and summary." : "Ordigi laŭ prioritato kaj resumo.",
    "Alphabetically" : "Alfabete",
    "Sort by summary and priority." : "Ordigi laŭ resumo kaj prioritato.",
    "Manually" : "Mane",
    "Sort by manual order." : "Ordigi permane",
    "{complete} % completed" : "{complete} % plenumita",
    "[Yesterday]" : "[Hieraŭ]",
    "[Today]" : "[Hodiaŭ]",
    "[Tomorrow]" : "[Morgaŭ]",
    "Add a subtask to \"{task}\"…" : "Aldoni subtaskon al „{task}\"“...",
    "Task is completed" : "Tasko plenumita.",
    "Cancel" : "Nuligi",
    "Close" : "Malfermi",
    "_%n Completed Task_::_%n Completed Tasks_" : ["%n plenumita tasko","%n plenumitaj taskoj"],
    "Tomorrow" : "Morgaŭ",
    "Add List…" : "Aldoni liston...",
    "All day" : "Tuttage",
    "Details" : "Detaloj",
    "Select a classification" : "Elektu klasifikon",
    "Select a status" : "Elekti staton",
    "Select tags" : "Elekti etikedojn",
    "Notes" : "Notoj",
    "Reminders" : "Memorigoj",
    "Repeat" : "Ripeti",
    "When shared show full event" : "Kiam kunhavigita, montri plenajn detalojn",
    "When shared show only busy" : "Kiam kunhavigita, montri nur kiel okupita",
    "When shared hide this event" : "Kiam kunhavigita, kaŝi tiun okazaĵon",
    "Needs action" : "Bezono de ago",
    "In process" : "Plenumado",
    "Canceled" : "Nuligita",
    "Loading task from server." : "Ricevo de la takso el la servilo.",
    "Task not found!" : "Tasko ne trovita!",
    "[Starts today]" : "[Komenciĝas hodiaŭ]",
    "[Starts tomorrow]" : "[Komenciĝos morgaŭ]",
    "[Starts on] LL" : "[Komenciĝas] LL",
    "[Started yesterday]" : "[Komenciĝis hieraŭ]",
    "[Started on] LL" : "[Komenciĝis] LL",
    "[Started today at] LT" : "[Komenciĝas hodiaŭ je] LT",
    "[Starts today at] LT" : "[Komenciĝas hodiaŭ je] LT",
    "[Starts tomorrow at] LT" : "[Komenciĝos morgaŭ je] LT",
    "[Starts on] LL [at] LT" : "[Komenciĝas] LL [je] LT",
    "[Started yesterday at] LT" : "[Komenciĝis hieraŭ je] LT",
    "[Started on] LL [at] LT" : "[Komenciĝis] LL [je] LT",
    "Set start date" : "Agordi komencdaton",
    "[Due today]" : "[Limdato hodiaŭa]",
    "[Due tomorrow]" : "[Limdato margaŭa]",
    "[Due on] LL" : "[Limdato] LL",
    "[Was due yesterday]" : "[Limdato hieraŭa]",
    "[Was due on] LL" : "[Limdato] LL",
    "[Was due today at] LT" : "[Limdato hodiaŭa je] LT",
    "[Due today at] LT" : "[Limdato hodiaŭa je] LT",
    "[Due tomorrow at] LT" : "[Limdato morgaŭa je] LT",
    "[Due on] LL [at] LT" : "[Limdato] LL [je] LT",
    "[Was due yesterday at] LT" : "[Limdato hieraŭa je] LT",
    "[Was due on] LL [at] LT" : "[Limdato] LL [je] LT",
    "Set due date" : "Agordi limdaton",
    "Priority {priority}: low" : "Prioritato {priority}: malalta",
    "Priority {priority}: medium" : "Prioritato {priority}: meza",
    "Priority {priority}: high" : "Prioritato {priority}: alta",
    "No priority assigned" : "Neniu prioritato",
    "{percent} % completed" : "{percent} % plenumitaj",
    "Could not delete the task." : "Ne eblis forigi la taskon.",
    "Synchronizing to the server." : "Sinkronigo al servilo.",
    "Task successfully saved to server." : "Tasko sukcese konservita en la servilo.",
    "Could not update the task because it was changed on the server. Please click to refresh it, local changes will be discarded." : "Ne eblis ĝisdatigi la taskon, ĉar ĝi ŝanĝiĝis en la servilo. Bv. alklaki por aktualigi ĝin; lokaj ŝanĝoj perdiĝos.",
    "Could not update the task." : "Ne eblis ĝisdatigi la taskon.",
    "An error occurred" : "Eraro okazis"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-app-tasks-0.16.1-1.0-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/tasks/l10n/eo.js <==
OC.L10N.register(
    "tasks",
    {
    "Important" : "Grava",
    "Today" : "Hodiaŭ",
    "Week" : "Semajno",
    "All" : "Ĉio",
    "Current" : "Nuna",
    "Completed" : "Plenumita",
    "Tasks" : "Taskoj",
    "The Tasks app for Nextcloud" : "Aplikaĵo „Taskoj“ por Nextcloud",
    "Default list" : "Defaŭlta listo",
    "Visibility of Smart Collections" : "Videbleco de aŭtomataj kolektoj",
    "Hidden" : "Nevidebla",
    "Visible" : "Videbla",
    "Automatic" : "Aŭtomata",
    "Share with users or groups" : "Kunhavigi kun uzantoj aŭ grupoj",
    "No users or groups" : "Neniu uzanto aŭ grupo",
    "Can edit" : "Povas redakti",
    "Unable to delete the share." : "Ne eblas forigi la kunhavon.",
    "Unable to change permissions." : "Ne eblas ŝanĝi permesojn.",
    "Edit" : "Redakti",
    "Copy private link" : "Kopii privatan ligilon",
    "Copied" : "Kopiita",
    "Export" : "Eksporti",
    "Delete" : "Forigi",
    "Unshare" : "Malkunhavigi",
    "This will delete the calendar \"{calendar}\" and all corresponding events and tasks." : "Tio forigos la kalendaron „{calendar}“ kaj ĉiujn ties eventojn kaj taskojn.",
    "Calendar link copied to clipboard." : "Kalendara ligilo kopiita al tondujo",
    "Calendar link could not be copied to clipboard." : "Kalendara ligilo ne eblis esti kopiita al tondujo",
    "The name \"{calendar}\" is already used." : "La nomo „{calendar}“ jam uziĝas.",
    "An empty name is not allowed." : "Malplena nomo ne permesatas.",
    "_Shared with {num} entity_::_Shared with {num} entities_" : ["Kunhavigitaj kun {num} ento","Kunhavigitaj kun {num} entoj"],
    "Name" : "Nomo",
    "Deleted" : "Forigita",
    "Restore" : "Restaŭri",
    "Delete permanently" : "Forigi por ĉiam",
    "Empty trash bin" : "Malpleni rubujon",
    "Untitled event" : "Sentitola okazaĵo",
    "Select a calendar" : "Elekti kalendaron",
    "Cancel" : "Nuligi",
    "Close" : "Malfermi",
    "Delete all completed tasks." : "Forigi ĉiujn plenumitajn taskojn.",
    "Delete completed tasks." : "Forigi plenumitajn taskojn.",
    "Deleted all completed tasks from calendar \"{calendar}\"." : "Forigi ĉiujn plenumitajn taskojn el kalendaro „{calendar}“.",
    "No errors" : "Neniu eraro",
    "Open your browser console for more details" : "Malfermu vian retumilan konzolon por pli da detaloj",
    "_This will delete {taskCount} completed task and its subtasks from calendar \"{calendar}\"._::_This will delete {taskCount} completed tasks and their subtasks from calendar \"{calendar}\"._" : ["Tio forigos {taskCount} plenumitan taskon kaj ties subtaskojn el la kalendaro „{calendar}“.","Tio forigos {taskCount} plenumitajn taskojn kaj ties subtaskojn el la kalendaro „{calendar}“."],
    "_Could not delete {failedCount} task._::_Could not delete {failedCount} tasks._" : ["Ne eblis forigi {failedCount} taskon.","Ne eblis forigi {failedCount} taskojn."],
    "Select tags to filter by" : "Elekti etikedojn, per kiuj filtri",
    "Add an important task to \"{calendar}\"…" : "Aldoni gravan taskon al „{calendar}“...",
    "Add a task due today to \"{calendar}\"…" : "Aldoni taskon kun hodiaŭa limdato al „{calendar}“...",
    "Add a current task to \"{calendar}\"…" : "Aldoni nunan taskon al „{calendar}“...",
    "Add a task to \"{calendar}\"…" : "Aldoni taskon al „{calendar}“...",
    "Change sort order" : "Ŝanĝi ordigon",
    "Sort by completed state, due date, priority, start date and summary." : "Ordigi laŭ plenumstato, limdato, prioritato, komencdato kaj resumo.",
    "Start date" : "Komencdato",
    "Due date" : "Limdato",
    "Created date" : "Krea dato",
    "Last modified" : "Laste modifita",
    "Completed date" : "Plenumdato",
    "Priority" : "Prioritato",
    "Sort by priority and summary." : "Ordigi laŭ prioritato kaj resumo.",
    "Alphabetically" : "Alfabete",
    "Sort by summary and priority." : "Ordigi laŭ resumo kaj prioritato.",
    "Manually" : "Mane",
    "Sort by manual order." : "Ordigi permane",
    "{complete} % completed" : "{complete} % plenumita",
    "[Yesterday]" : "[Hieraŭ]",
    "[Today]" : "[Hodiaŭ]",
    "[Tomorrow]" : "[Morgaŭ]",
    "Add a subtask to \"{task}\"…" : "Aldoni subtaskon al „{task}\"“...",
    "Task is completed" : "Tasko plenumita.",
    "_%n Completed Task_::_%n Completed Tasks_" : ["%n plenumita tasko","%n plenumitaj taskoj"],
    "Tomorrow" : "Morgaŭ",
    "Add List…" : "Aldoni liston...",
    "All day" : "Tuttage",
    "Details" : "Detaloj",
    "Select a classification" : "Elektu klasifikon",
    "Select a status" : "Elekti staton",
    "Select tags" : "Elekti etikedojn",
    "Notes" : "Notoj",
    "Reminders" : "Memorigoj",
    "Repeat" : "Ripeti",
    "When shared show full event" : "Kiam kunhavigita, montri plenajn detalojn",
    "When shared show only busy" : "Kiam kunhavigita, montri nur kiel okupita",
    "When shared hide this event" : "Kiam kunhavigita, kaŝi tiun okazaĵon",
    "Needs action" : "Bezono de ago",
    "In process" : "Plenumado",
    "Canceled" : "Nuligita",
    "Loading task from server." : "Ricevo de la takso el la servilo.",
    "Task not found!" : "Tasko ne trovita!",
    "Set start date" : "Agordi komencdaton",
    "Set due date" : "Agordi limdaton",
    "Priority {priority}: low" : "Prioritato {priority}: malalta",
    "Priority {priority}: medium" : "Prioritato {priority}: meza",
    "Priority {priority}: high" : "Prioritato {priority}: alta",
    "No priority assigned" : "Neniu prioritato",
    "{percent} % completed" : "{percent} % plenumitaj",
    "[Due today]" : "[Limdato hodiaŭa]",
    "[Due tomorrow]" : "[Limdato margaŭa]",
    "[Due today at] LT" : "[Limdato hodiaŭa je] LT",
    "[Due tomorrow at] LT" : "[Limdato morgaŭa je] LT",
    "Could not delete the task." : "Ne eblis forigi la taskon.",
    "Synchronizing to the server." : "Sinkronigo al servilo.",
    "Task successfully saved to server." : "Tasko sukcese konservita en la servilo.",
    "Could not update the task because it was changed on the server. Please click to refresh it, local changes will be discarded." : "Ne eblis ĝisdatigi la taskon, ĉar ĝi ŝanĝiĝis en la servilo. Bv. alklaki por aktualigi ĝin; lokaj ŝanĝoj perdiĝos.",
    "Could not update the task." : "Ne eblis ĝisdatigi la taskon.",
    "An error occurred" : "Eraro okazis",
    "[Due on] LL" : "[Limdato] LL",
    "[Was due yesterday]" : "[Limdato hieraŭa]",
    "[Was due on] LL" : "[Limdato] LL",
    "[Was due today at] LT" : "[Limdato hodiaŭa je] LT",
    "[Due on] LL [at] LT" : "[Limdato] LL [je] LT",
    "[Was due yesterday at] LT" : "[Limdato hieraŭa je] LT",
    "[Was due on] LL [at] LT" : "[Limdato] LL [je] LT",
    "[Starts today]" : "[Komenciĝas hodiaŭ]",
    "[Starts tomorrow]" : "[Komenciĝos morgaŭ]",
    "[Starts on] LL" : "[Komenciĝas] LL",
    "[Started yesterday]" : "[Komenciĝis hieraŭ]",
    "[Started on] LL" : "[Komenciĝis] LL",
    "[Started today at] LT" : "[Komenciĝas hodiaŭ je] LT",
    "[Starts today at] LT" : "[Komenciĝas hodiaŭ je] LT",
    "[Starts tomorrow at] LT" : "[Komenciĝos morgaŭ je] LT",
    "[Starts on] LL [at] LT" : "[Komenciĝas] LL [je] LT",
    "[Started yesterday at] LT" : "[Komenciĝis hieraŭ je] LT",
    "[Started on] LL [at] LT" : "[Komenciĝis] LL [je] LT"
},
"nplurals=2; plural=(n != 1);");
